# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUAlarmsFetcher
from ..fetchers import NUBootstrapActivationsFetcher
from ..fetchers import NUBootstrapsFetcher
from ..fetchers import NUEnterprisePermissionsFetcher
from ..fetchers import NUEventLogsFetcher
from ..fetchers import NUInfrastructureConfigsFetcher
from ..fetchers import NUJobsFetcher
from ..fetchers import NULocationsFetcher
from ..fetchers import NUPATNATPoolsFetcher
from ..fetchers import NUPermittedActionsFetcher

from bambou import NURESTObject


class NUNSGateway(NURESTObject):
    """ Represents a NSGateway in the VSD

        Notes:
            Represents Network Service Gateway object.

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NUNSGateway instead.
    """

    __rest_name__ = u"nsgateway"

    def __init__(self, **kwargs):
        """ Initializes a NSGateway instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> nsgateway = NUNSGateway(id=u'xxxx-xxx-xxx-xxx', name=u'NSGateway')
                >>> nsgateway = NUNSGateway(data=my_dict)
        """

        super(NUNSGateway, self).__init__()

        # Read/Write Attributes
        
        self._associated_gateway_security_id = None
        self._associated_gateway_security_profile_id = None
        self._auto_disc_gateway_id = None
        self._bootstrap_id = None
        self._configuration_reload_state = None
        self._configuration_status = None
        self._datapath_id = None
        self._description = None
        self._enterprise_id = None
        self._location_id = None
        self._name = None
        self._nat_traversal_enabled = None
        self._pending = None
        self._permitted_action = None
        self._personality = None
        self._ports = None
        self._redundancy_group_id = None
        self._system_id = None
        self._template_id = None
        
        self.expose_attribute(local_name=u"associated_gateway_security_id", remote_name=u"associatedGatewaySecurityId", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"associated_gateway_security_profile_id", remote_name=u"associatedGatewaySecurityProfileId", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"auto_disc_gateway_id", remote_name=u"autoDiscGatewayID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"bootstrap_id", remote_name=u"bootstrapID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"configuration_reload_state", remote_name=u"configurationReloadState", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"configuration_status", remote_name=u"configurationStatus", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"datapath_id", remote_name=u"datapathID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"description", remote_name=u"description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"enterprise_id", remote_name=u"enterpriseID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"location_id", remote_name=u"locationID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"name", remote_name=u"name", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name=u"nat_traversal_enabled", remote_name=u"NATTraversalEnabled", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"pending", remote_name=u"pending", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"permitted_action", remote_name=u"permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
        self.expose_attribute(local_name=u"personality", remote_name=u"personality", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"ports", remote_name=u"ports", attribute_type=list, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"redundancy_group_id", remote_name=u"redundancyGroupID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"system_id", remote_name=u"systemID", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"template_id", remote_name=u"templateID", attribute_type=str, is_required=True, is_unique=False)
        
        # Fetchers
        
        self.alarms = NUAlarmsFetcher.fetcher_with_object(parent_object=self)
        
        self.bootstrap_activations = NUBootstrapActivationsFetcher.fetcher_with_object(parent_object=self)
        
        self.bootstraps = NUBootstrapsFetcher.fetcher_with_object(parent_object=self)
        
        self.enterprise_permissions = NUEnterprisePermissionsFetcher.fetcher_with_object(parent_object=self)
        
        self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self)
        
        self.infrastructure_configs = NUInfrastructureConfigsFetcher.fetcher_with_object(parent_object=self)
        
        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self)
        
        self.locations = NULocationsFetcher.fetcher_with_object(parent_object=self)
        
        self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self)
        
        self.permitted_actions = NUPermittedActionsFetcher.fetcher_with_object(parent_object=self)
        
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_associated_gateway_security_id(self):
        """ Get associated_gateway_security_id value.

            Notes:
                Readonly Id of the associated gateway security object

                
                This attribute is named `associatedGatewaySecurityId` in VSD API.
                
        """
        return self._associated_gateway_security_id

    def _set_associated_gateway_security_id(self, value):
        """ Set associated_gateway_security_id value.

            Notes:
                Readonly Id of the associated gateway security object

                
                This attribute is named `associatedGatewaySecurityId` in VSD API.
                
        """
        self._associated_gateway_security_id = value

    associated_gateway_security_id = property(_get_associated_gateway_security_id, _set_associated_gateway_security_id)
    
    def _get_associated_gateway_security_profile_id(self):
        """ Get associated_gateway_security_profile_id value.

            Notes:
                Readonly Id of the associated gateway security profile object

                
                This attribute is named `associatedGatewaySecurityProfileId` in VSD API.
                
        """
        return self._associated_gateway_security_profile_id

    def _set_associated_gateway_security_profile_id(self, value):
        """ Set associated_gateway_security_profile_id value.

            Notes:
                Readonly Id of the associated gateway security profile object

                
                This attribute is named `associatedGatewaySecurityProfileId` in VSD API.
                
        """
        self._associated_gateway_security_profile_id = value

    associated_gateway_security_profile_id = property(_get_associated_gateway_security_profile_id, _set_associated_gateway_security_profile_id)
    
    def _get_auto_disc_gateway_id(self):
        """ Get auto_disc_gateway_id value.

            Notes:
                The Auto Discovered Gateway associated with this Gateway Instance

                
                This attribute is named `autoDiscGatewayID` in VSD API.
                
        """
        return self._auto_disc_gateway_id

    def _set_auto_disc_gateway_id(self, value):
        """ Set auto_disc_gateway_id value.

            Notes:
                The Auto Discovered Gateway associated with this Gateway Instance

                
                This attribute is named `autoDiscGatewayID` in VSD API.
                
        """
        self._auto_disc_gateway_id = value

    auto_disc_gateway_id = property(_get_auto_disc_gateway_id, _set_auto_disc_gateway_id)
    
    def _get_bootstrap_id(self):
        """ Get bootstrap_id value.

            Notes:
                The bootstrap details associated with this NSGateway. NOTE: this is a read only property, it can only be set during creation of an NSG

                
                This attribute is named `bootstrapID` in VSD API.
                
        """
        return self._bootstrap_id

    def _set_bootstrap_id(self, value):
        """ Set bootstrap_id value.

            Notes:
                The bootstrap details associated with this NSGateway. NOTE: this is a read only property, it can only be set during creation of an NSG

                
                This attribute is named `bootstrapID` in VSD API.
                
        """
        self._bootstrap_id = value

    bootstrap_id = property(_get_bootstrap_id, _set_bootstrap_id)
    
    def _get_configuration_reload_state(self):
        """ Get configuration_reload_state value.

            Notes:
                

                
                This attribute is named `configurationReloadState` in VSD API.
                
        """
        return self._configuration_reload_state

    def _set_configuration_reload_state(self, value):
        """ Set configuration_reload_state value.

            Notes:
                

                
                This attribute is named `configurationReloadState` in VSD API.
                
        """
        self._configuration_reload_state = value

    configuration_reload_state = property(_get_configuration_reload_state, _set_configuration_reload_state)
    
    def _get_configuration_status(self):
        """ Get configuration_status value.

            Notes:
                

                
                This attribute is named `configurationStatus` in VSD API.
                
        """
        return self._configuration_status

    def _set_configuration_status(self, value):
        """ Set configuration_status value.

            Notes:
                

                
                This attribute is named `configurationStatus` in VSD API.
                
        """
        self._configuration_status = value

    configuration_status = property(_get_configuration_status, _set_configuration_status)
    
    def _get_datapath_id(self):
        """ Get datapath_id value.

            Notes:
                Identifier of the Gateway, based on the systemId

                
                This attribute is named `datapathID` in VSD API.
                
        """
        return self._datapath_id

    def _set_datapath_id(self, value):
        """ Set datapath_id value.

            Notes:
                Identifier of the Gateway, based on the systemId

                
                This attribute is named `datapathID` in VSD API.
                
        """
        self._datapath_id = value

    datapath_id = property(_get_datapath_id, _set_datapath_id)
    
    def _get_description(self):
        """ Get description value.

            Notes:
                A description of the Gateway

                
        """
        return self._description

    def _set_description(self, value):
        """ Set description value.

            Notes:
                A description of the Gateway

                
        """
        self._description = value

    description = property(_get_description, _set_description)
    
    def _get_enterprise_id(self):
        """ Get enterprise_id value.

            Notes:
                The enterprise associated with this Gateway. This is a read only attribute

                
                This attribute is named `enterpriseID` in VSD API.
                
        """
        return self._enterprise_id

    def _set_enterprise_id(self, value):
        """ Set enterprise_id value.

            Notes:
                The enterprise associated with this Gateway. This is a read only attribute

                
                This attribute is named `enterpriseID` in VSD API.
                
        """
        self._enterprise_id = value

    enterprise_id = property(_get_enterprise_id, _set_enterprise_id)
    
    def _get_location_id(self):
        """ Get location_id value.

            Notes:
                The NSGateway's Location. NOTE: this is a read only property, it can only be set through the location object

                
                This attribute is named `locationID` in VSD API.
                
        """
        return self._location_id

    def _set_location_id(self, value):
        """ Set location_id value.

            Notes:
                The NSGateway's Location. NOTE: this is a read only property, it can only be set through the location object

                
                This attribute is named `locationID` in VSD API.
                
        """
        self._location_id = value

    location_id = property(_get_location_id, _set_location_id)
    
    def _get_name(self):
        """ Get name value.

            Notes:
                Name of the Gateway

                
        """
        return self._name

    def _set_name(self, value):
        """ Set name value.

            Notes:
                Name of the Gateway

                
        """
        self._name = value

    name = property(_get_name, _set_name)
    
    def _get_nat_traversal_enabled(self):
        """ Get nat_traversal_enabled value.

            Notes:
                Boolean value that states if the NSG instance is in a network that is behind a NAT device and will use NAT Traversal procedures to talk to other NSGs and the Internet.

                
                This attribute is named `NATTraversalEnabled` in VSD API.
                
        """
        return self._nat_traversal_enabled

    def _set_nat_traversal_enabled(self, value):
        """ Set nat_traversal_enabled value.

            Notes:
                Boolean value that states if the NSG instance is in a network that is behind a NAT device and will use NAT Traversal procedures to talk to other NSGs and the Internet.

                
                This attribute is named `NATTraversalEnabled` in VSD API.
                
        """
        self._nat_traversal_enabled = value

    nat_traversal_enabled = property(_get_nat_traversal_enabled, _set_nat_traversal_enabled)
    
    def _get_pending(self):
        """ Get pending value.

            Notes:
                Indicates that this gateway is pending state or state. When in pending state it cannot be modified from REST.

                
        """
        return self._pending

    def _set_pending(self, value):
        """ Set pending value.

            Notes:
                Indicates that this gateway is pending state or state. When in pending state it cannot be modified from REST.

                
        """
        self._pending = value

    pending = property(_get_pending, _set_pending)
    
    def _get_permitted_action(self):
        """ Get permitted_action value.

            Notes:
                The permitted  action to USE/EXTEND  this Gateway Possible values are USE, READ, ALL, INSTANTIATE, EXTEND, DEPLOY, .

                
                This attribute is named `permittedAction` in VSD API.
                
        """
        return self._permitted_action

    def _set_permitted_action(self, value):
        """ Set permitted_action value.

            Notes:
                The permitted  action to USE/EXTEND  this Gateway Possible values are USE, READ, ALL, INSTANTIATE, EXTEND, DEPLOY, .

                
                This attribute is named `permittedAction` in VSD API.
                
        """
        self._permitted_action = value

    permitted_action = property(_get_permitted_action, _set_permitted_action)
    
    def _get_personality(self):
        """ Get personality value.

            Notes:
                Personality of the Gateway - NSG, cannot be changed after creation.

                
        """
        return self._personality

    def _set_personality(self, value):
        """ Set personality value.

            Notes:
                Personality of the Gateway - NSG, cannot be changed after creation.

                
        """
        self._personality = value

    personality = property(_get_personality, _set_personality)
    
    def _get_ports(self):
        """ Get ports value.

            Notes:
                Collection of ports associated with the NSG.

                
        """
        return self._ports

    def _set_ports(self, value):
        """ Set ports value.

            Notes:
                Collection of ports associated with the NSG.

                
        """
        self._ports = value

    ports = property(_get_ports, _set_ports)
    
    def _get_redundancy_group_id(self):
        """ Get redundancy_group_id value.

            Notes:
                The Redundancy Gateway Group associated with this Gateway Instance. This is a read only attribute

                
                This attribute is named `redundancyGroupID` in VSD API.
                
        """
        return self._redundancy_group_id

    def _set_redundancy_group_id(self, value):
        """ Set redundancy_group_id value.

            Notes:
                The Redundancy Gateway Group associated with this Gateway Instance. This is a read only attribute

                
                This attribute is named `redundancyGroupID` in VSD API.
                
        """
        self._redundancy_group_id = value

    redundancy_group_id = property(_get_redundancy_group_id, _set_redundancy_group_id)
    
    def _get_system_id(self):
        """ Get system_id value.

            Notes:
                Identifier of the Gateway, cannot be modified after creation

                
                This attribute is named `systemID` in VSD API.
                
        """
        return self._system_id

    def _set_system_id(self, value):
        """ Set system_id value.

            Notes:
                Identifier of the Gateway, cannot be modified after creation

                
                This attribute is named `systemID` in VSD API.
                
        """
        self._system_id = value

    system_id = property(_get_system_id, _set_system_id)
    
    def _get_template_id(self):
        """ Get template_id value.

            Notes:
                The ID of the template that this Gateway was created from. This should be set when instantiating a Gateway

                
                This attribute is named `templateID` in VSD API.
                
        """
        return self._template_id

    def _set_template_id(self, value):
        """ Set template_id value.

            Notes:
                The ID of the template that this Gateway was created from. This should be set when instantiating a Gateway

                
                This attribute is named `templateID` in VSD API.
                
        """
        self._template_id = value

    template_id = property(_get_template_id, _set_template_id)
    