# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUMetadatasFetcher
from bambou import NURESTObject


class NUAggregateMetadata(NURESTObject):
    """ Represents a AggregateMetadata in the VSD

        Notes:
            Metadata associated to a entity

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NUAggregateMetadata instead.
    """

    __rest_name__ = u"aggregatemetadata"

    def __init__(self, **kwargs):
        """ Initializes a AggregateMetadata instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> aggregatemetadata = NUAggregateMetadata(id=u'xxxx-xxx-xxx-xxx', name=u'AggregateMetadata')
                >>> aggregatemetadata = NUAggregateMetadata(data=my_dict)
        """

        super(NUAggregateMetadata, self).__init__()

        # Read/Write Attributes
        
        self._blob = None
        self._description = None
        self._global_metadata = None
        self._metadata_tag_ids = None
        self._name = None
        self._network_notification_disabled = None
        
        self.expose_attribute(local_name=u"blob", remote_name=u"blob", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name=u"description", remote_name=u"description", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"global_metadata", remote_name=u"global", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"metadata_tag_ids", remote_name=u"metadataTagIDs", attribute_type=list, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"name", remote_name=u"name", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"network_notification_disabled", remote_name=u"networkNotificationDisabled", attribute_type=bool, is_required=False, is_unique=False)
        
        
        self.metadata = NUMetadatasFetcher.fetcher_with_object(parent_object=self)
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_blob(self):
        """ Get blob value.

            Notes:
                Metadata that describes about the entity attached to it.

                
        """
        return self._blob

    def _set_blob(self, value):
        """ Set blob value.

            Notes:
                Metadata that describes about the entity attached to it.

                
        """
        self._blob = value

    blob = property(_get_blob, _set_blob)
    
    def _get_description(self):
        """ Get description value.

            Notes:
                Description of the Metadata.

                
        """
        return self._description

    def _set_description(self, value):
        """ Set description value.

            Notes:
                Description of the Metadata.

                
        """
        self._description = value

    description = property(_get_description, _set_description)
    
    def _get_global_metadata(self):
        """ Get global_metadata value.

            Notes:
                specifies metadata is global or local

                
                This attribute is named `global` in VSD API.
                
        """
        return self._global_metadata

    def _set_global_metadata(self, value):
        """ Set global_metadata value.

            Notes:
                specifies metadata is global or local

                
                This attribute is named `global` in VSD API.
                
        """
        self._global_metadata = value

    global_metadata = property(_get_global_metadata, _set_global_metadata)
    
    def _get_metadata_tag_ids(self):
        """ Get metadata_tag_ids value.

            Notes:
                metadata tag IDs associated with this metadata you can filter metadata based on this attribute for example  X-Nuage-Filter: '2d6fb627-603b-421c-b63a-eb0a6d712761' IN metadataTagIDs 

                
                This attribute is named `metadataTagIDs` in VSD API.
                
        """
        return self._metadata_tag_ids

    def _set_metadata_tag_ids(self, value):
        """ Set metadata_tag_ids value.

            Notes:
                metadata tag IDs associated with this metadata you can filter metadata based on this attribute for example  X-Nuage-Filter: '2d6fb627-603b-421c-b63a-eb0a6d712761' IN metadataTagIDs 

                
                This attribute is named `metadataTagIDs` in VSD API.
                
        """
        self._metadata_tag_ids = value

    metadata_tag_ids = property(_get_metadata_tag_ids, _set_metadata_tag_ids)
    
    def _get_name(self):
        """ Get name value.

            Notes:
                name of the Metadata.

                
        """
        return self._name

    def _set_name(self, value):
        """ Set name value.

            Notes:
                name of the Metadata.

                
        """
        self._name = value

    name = property(_get_name, _set_name)
    
    def _get_network_notification_disabled(self):
        """ Get network_notification_disabled value.

            Notes:
                specifies metadata changes need to be notified to controller,by default it is notified

                
                This attribute is named `networkNotificationDisabled` in VSD API.
                
        """
        return self._network_notification_disabled

    def _set_network_notification_disabled(self, value):
        """ Set network_notification_disabled value.

            Notes:
                specifies metadata changes need to be notified to controller,by default it is notified

                
                This attribute is named `networkNotificationDisabled` in VSD API.
                
        """
        self._network_notification_disabled = value

    network_notification_disabled = property(_get_network_notification_disabled, _set_network_notification_disabled)
    