# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUMetadatasFetcher
from bambou import NURESTObject


class NUBGPPeer(NURESTObject):
    """ Represents a BGPPeer in the VSD

        Notes:
            Encapsulates the BGP peer information for system monitor entity.

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NUBGPPeer instead.
    """

    __rest_name__ = u"bgppeer"

    def __init__(self, **kwargs):
        """ Initializes a BGPPeer instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> bgppeer = NUBGPPeer(id=u'xxxx-xxx-xxx-xxx', name=u'BGPPeer')
                >>> bgppeer = NUBGPPeer(data=my_dict)
        """

        super(NUBGPPeer, self).__init__()

        # Read/Write Attributes
        
        self._address = None
        self._last_state_change = None
        self._status = None
        
        self.expose_attribute(local_name=u"address", remote_name=u"address", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"last_state_change", remote_name=u"lastStateChange", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"status", remote_name=u"status", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMIN_DOWN', u'DOWN', u'UP'])
        
        
        self.metadata = NUMetadatasFetcher.fetcher_with_object(parent_object=self)
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_address(self):
        """ Get address value.

            Notes:
                IP of the BGP peer.

                
        """
        return self._address

    def _set_address(self, value):
        """ Set address value.

            Notes:
                IP of the BGP peer.

                
        """
        self._address = value

    address = property(_get_address, _set_address)
    
    def _get_last_state_change(self):
        """ Get last_state_change value.

            Notes:
                Last state change timestamp.

                
                This attribute is named `lastStateChange` in VSD API.
                
        """
        return self._last_state_change

    def _set_last_state_change(self, value):
        """ Set last_state_change value.

            Notes:
                Last state change timestamp.

                
                This attribute is named `lastStateChange` in VSD API.
                
        """
        self._last_state_change = value

    last_state_change = property(_get_last_state_change, _set_last_state_change)
    
    def _get_status(self):
        """ Get status value.

            Notes:
                Current connection status of the BGP peer. Possible values are UP, DOWN, ADMIN_DOWN, .

                
        """
        return self._status

    def _set_status(self, value):
        """ Set status value.

            Notes:
                Current connection status of the BGP peer. Possible values are UP, DOWN, ADMIN_DOWN, .

                
        """
        self._status = value

    status = property(_get_status, _set_status)
    