# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUKeyServerMonitorEncryptedSeedsFetcher
from ..fetchers import NUKeyServerMonitorEncryptedSEKsFetcher
from ..fetchers import NUKeyServerMonitorSeedsFetcher
from ..fetchers import NUKeyServerMonitorSEKsFetcher
from ..fetchers import NUMetadatasFetcher
from bambou import NURESTObject


class NUKeyServerMonitor(NURESTObject):
    """ Represents a KeyServerMonitor in the VSD

        Notes:
            Represents a Keyserver Monitor Snapshot

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NUKeyServerMonitor instead.
    """

    __rest_name__ = u"keyservermonitor"

    def __init__(self, **kwargs):
        """ Initializes a KeyServerMonitor instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> keyservermonitor = NUKeyServerMonitor(id=u'xxxx-xxx-xxx-xxx', name=u'KeyServerMonitor')
                >>> keyservermonitor = NUKeyServerMonitor(data=my_dict)
        """

        super(NUKeyServerMonitor, self).__init__()

        # Read/Write Attributes
        
        self._enterprise_secured_data_record_count = None
        self._gateway_secured_data_record_count = None
        self._keyserver_monitor_encrypted_seed_count = None
        self._keyserver_monitor_encrypted_sek_count = None
        self._keyserver_monitor_seed_count = None
        self._keyserver_monitor_sek_count = None
        self._last_update_time = None
        
        self.expose_attribute(local_name=u"enterprise_secured_data_record_count", remote_name=u"enterpriseSecuredDataRecordCount", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"gateway_secured_data_record_count", remote_name=u"gatewaySecuredDataRecordCount", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"keyserver_monitor_encrypted_seed_count", remote_name=u"keyserverMonitorEncryptedSeedCount", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"keyserver_monitor_encrypted_sek_count", remote_name=u"keyserverMonitorEncryptedSEKCount", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"keyserver_monitor_seed_count", remote_name=u"keyserverMonitorSeedCount", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"keyserver_monitor_sek_count", remote_name=u"keyserverMonitorSEKCount", attribute_type=long, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"last_update_time", remote_name=u"lastUpdateTime", attribute_type=long, is_required=False, is_unique=False)
        
        # Fetchers
        
        self.key_server_monitor_encrypted_seeds = NUKeyServerMonitorEncryptedSeedsFetcher.fetcher_with_object(parent_object=self)
        
        self.key_server_monitor_encrypted_seks = NUKeyServerMonitorEncryptedSEKsFetcher.fetcher_with_object(parent_object=self)
        
        self.key_server_monitor_seeds = NUKeyServerMonitorSeedsFetcher.fetcher_with_object(parent_object=self)
        
        self.key_server_monitor_seks = NUKeyServerMonitorSEKsFetcher.fetcher_with_object(parent_object=self)
        
        
        self.metadata = NUMetadatasFetcher.fetcher_with_object(parent_object=self)
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_enterprise_secured_data_record_count(self):
        """ Get enterprise_secured_data_record_count value.

            Notes:
                Total number of Enterprise Secured Data records

                
                This attribute is named `enterpriseSecuredDataRecordCount` in VSD API.
                
        """
        return self._enterprise_secured_data_record_count

    def _set_enterprise_secured_data_record_count(self, value):
        """ Set enterprise_secured_data_record_count value.

            Notes:
                Total number of Enterprise Secured Data records

                
                This attribute is named `enterpriseSecuredDataRecordCount` in VSD API.
                
        """
        self._enterprise_secured_data_record_count = value

    enterprise_secured_data_record_count = property(_get_enterprise_secured_data_record_count, _set_enterprise_secured_data_record_count)
    
    def _get_gateway_secured_data_record_count(self):
        """ Get gateway_secured_data_record_count value.

            Notes:
                Total number of Gateway Secured Data records

                
                This attribute is named `gatewaySecuredDataRecordCount` in VSD API.
                
        """
        return self._gateway_secured_data_record_count

    def _set_gateway_secured_data_record_count(self, value):
        """ Set gateway_secured_data_record_count value.

            Notes:
                Total number of Gateway Secured Data records

                
                This attribute is named `gatewaySecuredDataRecordCount` in VSD API.
                
        """
        self._gateway_secured_data_record_count = value

    gateway_secured_data_record_count = property(_get_gateway_secured_data_record_count, _set_gateway_secured_data_record_count)
    
    def _get_keyserver_monitor_encrypted_seed_count(self):
        """ Get keyserver_monitor_encrypted_seed_count value.

            Notes:
                Total number of Keyserver Monitor Encrypted Seed records

                
                This attribute is named `keyserverMonitorEncryptedSeedCount` in VSD API.
                
        """
        return self._keyserver_monitor_encrypted_seed_count

    def _set_keyserver_monitor_encrypted_seed_count(self, value):
        """ Set keyserver_monitor_encrypted_seed_count value.

            Notes:
                Total number of Keyserver Monitor Encrypted Seed records

                
                This attribute is named `keyserverMonitorEncryptedSeedCount` in VSD API.
                
        """
        self._keyserver_monitor_encrypted_seed_count = value

    keyserver_monitor_encrypted_seed_count = property(_get_keyserver_monitor_encrypted_seed_count, _set_keyserver_monitor_encrypted_seed_count)
    
    def _get_keyserver_monitor_encrypted_sek_count(self):
        """ Get keyserver_monitor_encrypted_sek_count value.

            Notes:
                Total number of Keyserver Monitor Encrypted SEK records

                
                This attribute is named `keyserverMonitorEncryptedSEKCount` in VSD API.
                
        """
        return self._keyserver_monitor_encrypted_sek_count

    def _set_keyserver_monitor_encrypted_sek_count(self, value):
        """ Set keyserver_monitor_encrypted_sek_count value.

            Notes:
                Total number of Keyserver Monitor Encrypted SEK records

                
                This attribute is named `keyserverMonitorEncryptedSEKCount` in VSD API.
                
        """
        self._keyserver_monitor_encrypted_sek_count = value

    keyserver_monitor_encrypted_sek_count = property(_get_keyserver_monitor_encrypted_sek_count, _set_keyserver_monitor_encrypted_sek_count)
    
    def _get_keyserver_monitor_seed_count(self):
        """ Get keyserver_monitor_seed_count value.

            Notes:
                Total number of Keyserver Monitor Seed records

                
                This attribute is named `keyserverMonitorSeedCount` in VSD API.
                
        """
        return self._keyserver_monitor_seed_count

    def _set_keyserver_monitor_seed_count(self, value):
        """ Set keyserver_monitor_seed_count value.

            Notes:
                Total number of Keyserver Monitor Seed records

                
                This attribute is named `keyserverMonitorSeedCount` in VSD API.
                
        """
        self._keyserver_monitor_seed_count = value

    keyserver_monitor_seed_count = property(_get_keyserver_monitor_seed_count, _set_keyserver_monitor_seed_count)
    
    def _get_keyserver_monitor_sek_count(self):
        """ Get keyserver_monitor_sek_count value.

            Notes:
                Total number of Keyserver Monitor SEK records

                
                This attribute is named `keyserverMonitorSEKCount` in VSD API.
                
        """
        return self._keyserver_monitor_sek_count

    def _set_keyserver_monitor_sek_count(self, value):
        """ Set keyserver_monitor_sek_count value.

            Notes:
                Total number of Keyserver Monitor SEK records

                
                This attribute is named `keyserverMonitorSEKCount` in VSD API.
                
        """
        self._keyserver_monitor_sek_count = value

    keyserver_monitor_sek_count = property(_get_keyserver_monitor_sek_count, _set_keyserver_monitor_sek_count)
    
    def _get_last_update_time(self):
        """ Get last_update_time value.

            Notes:
                The time the latest SEK or Seed was created/removed (milliseconds since epoch)

                
                This attribute is named `lastUpdateTime` in VSD API.
                
        """
        return self._last_update_time

    def _set_last_update_time(self, value):
        """ Set last_update_time value.

            Notes:
                The time the latest SEK or Seed was created/removed (milliseconds since epoch)

                
                This attribute is named `lastUpdateTime` in VSD API.
                
        """
        self._last_update_time = value

    last_update_time = property(_get_last_update_time, _set_last_update_time)
    