# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUMetadatasFetcher
from bambou import NURESTObject


class NULocation(NURESTObject):
    """ Represents a Location in the VSD

        Notes:
            Gateway location details

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NULocation instead.
    """

    __rest_name__ = u"location"

    def __init__(self, **kwargs):
        """ Initializes a Location instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> location = NULocation(id=u'xxxx-xxx-xxx-xxx', name=u'Location')
                >>> location = NULocation(data=my_dict)
        """

        super(NULocation, self).__init__()

        # Read/Write Attributes
        
        self._address = None
        self._country = None
        self._ignore_geocode = None
        self._latitude = None
        self._locality = None
        self._longitude = None
        self._state = None
        self._time_zone_id = None
        
        self.expose_attribute(local_name=u"address", remote_name=u"address", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"country", remote_name=u"country", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"ignore_geocode", remote_name=u"ignoreGeocode", attribute_type=bool, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"latitude", remote_name=u"latitude", attribute_type=float, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"locality", remote_name=u"locality", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"longitude", remote_name=u"longitude", attribute_type=float, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"state", remote_name=u"state", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"time_zone_id", remote_name=u"timeZoneID", attribute_type=str, is_required=False, is_unique=False)
        
        
        self.metadata = NUMetadatasFetcher.fetcher_with_object(parent_object=self)
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_address(self):
        """ Get address value.

            Notes:
                Formatted address including property number, street name, suite or office number, ...

                
        """
        return self._address

    def _set_address(self, value):
        """ Set address value.

            Notes:
                Formatted address including property number, street name, suite or office number, ...

                
        """
        self._address = value

    address = property(_get_address, _set_address)
    
    def _get_country(self):
        """ Get country value.

            Notes:
                Country

                
        """
        return self._country

    def _set_country(self, value):
        """ Set country value.

            Notes:
                Country

                
        """
        self._country = value

    country = property(_get_country, _set_country)
    
    def _get_ignore_geocode(self):
        """ Get ignore_geocode value.

            Notes:
                Request BSS to perform a geocode on the address - If no value passed, requestGeocode will be set to true

                
                This attribute is named `ignoreGeocode` in VSD API.
                
        """
        return self._ignore_geocode

    def _set_ignore_geocode(self, value):
        """ Set ignore_geocode value.

            Notes:
                Request BSS to perform a geocode on the address - If no value passed, requestGeocode will be set to true

                
                This attribute is named `ignoreGeocode` in VSD API.
                
        """
        self._ignore_geocode = value

    ignore_geocode = property(_get_ignore_geocode, _set_ignore_geocode)
    
    def _get_latitude(self):
        """ Get latitude value.

            Notes:
                Latitude in decimal format.

                
        """
        return self._latitude

    def _set_latitude(self, value):
        """ Set latitude value.

            Notes:
                Latitude in decimal format.

                
        """
        self._latitude = value

    latitude = property(_get_latitude, _set_latitude)
    
    def _get_locality(self):
        """ Get locality value.

            Notes:
                Locality/City/County

                
        """
        return self._locality

    def _set_locality(self, value):
        """ Set locality value.

            Notes:
                Locality/City/County

                
        """
        self._locality = value

    locality = property(_get_locality, _set_locality)
    
    def _get_longitude(self):
        """ Get longitude value.

            Notes:
                Longitude in decimal format.

                
        """
        return self._longitude

    def _set_longitude(self, value):
        """ Set longitude value.

            Notes:
                Longitude in decimal format.

                
        """
        self._longitude = value

    longitude = property(_get_longitude, _set_longitude)
    
    def _get_state(self):
        """ Get state value.

            Notes:
                State/Province/Region

                
        """
        return self._state

    def _set_state(self, value):
        """ Set state value.

            Notes:
                State/Province/Region

                
        """
        self._state = value

    state = property(_get_state, _set_state)
    
    def _get_time_zone_id(self):
        """ Get time_zone_id value.

            Notes:
                Time zone in which the Gateway is located.  This can be in the form of a UTC/GMT offset, continent/city location, or country/region.  The available time zones can be found in /usr/share/zoneinfo on a Linux machine or retrieved with TimeZone.getAvailableIDs() in Java.  Refer to the IANA (Internet Assigned Numbers Authority) for a list of time zones.  URL :  http://www.iana.org/time-zones  Default value is UTC (translating to Etc/Zulu)

                
                This attribute is named `timeZoneID` in VSD API.
                
        """
        return self._time_zone_id

    def _set_time_zone_id(self, value):
        """ Set time_zone_id value.

            Notes:
                Time zone in which the Gateway is located.  This can be in the form of a UTC/GMT offset, continent/city location, or country/region.  The available time zones can be found in /usr/share/zoneinfo on a Linux machine or retrieved with TimeZone.getAvailableIDs() in Java.  Refer to the IANA (Internet Assigned Numbers Authority) for a list of time zones.  URL :  http://www.iana.org/time-zones  Default value is UTC (translating to Etc/Zulu)

                
                This attribute is named `timeZoneID` in VSD API.
                
        """
        self._time_zone_id = value

    time_zone_id = property(_get_time_zone_id, _set_time_zone_id)
    