# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUVPortMirrorsFetcher
from ..fetchers import NUMetadatasFetcher
from bambou import NURESTObject


class NUMirrorDestination(NURESTObject):
    """ Represents a MirrorDestination in the VSD

        Notes:
            Represents the mirror destination entity.

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NUMirrorDestination instead.
    """

    __rest_name__ = u"mirrordestination"

    def __init__(self, **kwargs):
        """ Initializes a MirrorDestination instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> mirrordestination = NUMirrorDestination(id=u'xxxx-xxx-xxx-xxx', name=u'MirrorDestination')
                >>> mirrordestination = NUMirrorDestination(data=my_dict)
        """

        super(NUMirrorDestination, self).__init__()

        # Read/Write Attributes
        
        self._destination_ip = None
        self._name = None
        self._service_id = None
        
        self.expose_attribute(local_name=u"destination_ip", remote_name=u"destinationIp", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"name", remote_name=u"name", attribute_type=str, is_required=False, is_unique=False)
        self.expose_attribute(local_name=u"service_id", remote_name=u"serviceId", attribute_type=long, is_required=False, is_unique=False)
        
        # Fetchers
        
        self.vport_mirrors = NUVPortMirrorsFetcher.fetcher_with_object(parent_object=self)
        
        
        self.metadata = NUMetadatasFetcher.fetcher_with_object(parent_object=self)
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_destination_ip(self):
        """ Get destination_ip value.

            Notes:
                IP address of the destination server where you want your traffic to be mirrored.

                
                This attribute is named `destinationIp` in VSD API.
                
        """
        return self._destination_ip

    def _set_destination_ip(self, value):
        """ Set destination_ip value.

            Notes:
                IP address of the destination server where you want your traffic to be mirrored.

                
                This attribute is named `destinationIp` in VSD API.
                
        """
        self._destination_ip = value

    destination_ip = property(_get_destination_ip, _set_destination_ip)
    
    def _get_name(self):
        """ Get name value.

            Notes:
                Name of the mirror destination. Valid characters are alphabets, numbers, space and hyphen( - ).

                
        """
        return self._name

    def _set_name(self, value):
        """ Set name value.

            Notes:
                Name of the mirror destination. Valid characters are alphabets, numbers, space and hyphen( - ).

                
        """
        self._name = value

    name = property(_get_name, _set_name)
    
    def _get_service_id(self):
        """ Get service_id value.

            Notes:
                Service ID of the mirror destination.

                
                This attribute is named `serviceId` in VSD API.
                
        """
        return self._service_id

    def _set_service_id(self, value):
        """ Set service_id value.

            Notes:
                Service ID of the mirror destination.

                
                This attribute is named `serviceId` in VSD API.
                
        """
        self._service_id = value

    service_id = property(_get_service_id, _set_service_id)
    