# -*- coding: utf-8 -*-
#
# Copyright (c) 2015, Alcatel-Lucent Inc
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the copyright holder nor the names of its contributors
#       may be used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


from ..fetchers import NUEventLogsFetcher
from ..fetchers import NUMetadatasFetcher
from bambou import NURESTObject


class NUMultiCastRange(NURESTObject):
    """ Represents a MultiCastRange in the VSD

        Notes:
            This is the definition of a MultiCast Range associated with a MultiCast Channel Map

        Warning:
            This file has been autogenerated. You should never change it.
            Override vsdk.NUMultiCastRange instead.
    """

    __rest_name__ = u"multicastrange"

    def __init__(self, **kwargs):
        """ Initializes a MultiCastRange instance

            Notes:
                You can specify all parameters while calling this methods.
                A special argument named `data` will enable you to load the
                object from a Python dictionary

            Examples:
                >>> multicastrange = NUMultiCastRange(id=u'xxxx-xxx-xxx-xxx', name=u'MultiCastRange')
                >>> multicastrange = NUMultiCastRange(data=my_dict)
        """

        super(NUMultiCastRange, self).__init__()

        # Read/Write Attributes
        
        self._max_address = None
        self._min_address = None
        
        self.expose_attribute(local_name=u"max_address", remote_name=u"maxAddress", attribute_type=str, is_required=True, is_unique=False)
        self.expose_attribute(local_name=u"min_address", remote_name=u"minAddress", attribute_type=str, is_required=True, is_unique=False)
        
        # Fetchers
        
        self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self)
        
        
        self.metadata = NUMetadatasFetcher.fetcher_with_object(parent_object=self)
        

        self._compute_args(**kwargs)

    # Properties
    
    def _get_max_address(self):
        """ Get max_address value.

            Notes:
                Highest address in the MultiCast range

                
                This attribute is named `maxAddress` in VSD API.
                
        """
        return self._max_address

    def _set_max_address(self, value):
        """ Set max_address value.

            Notes:
                Highest address in the MultiCast range

                
                This attribute is named `maxAddress` in VSD API.
                
        """
        self._max_address = value

    max_address = property(_get_max_address, _set_max_address)
    
    def _get_min_address(self):
        """ Get min_address value.

            Notes:
                Lowest address in the MultiCast range

                
                This attribute is named `minAddress` in VSD API.
                
        """
        return self._min_address

    def _set_min_address(self, value):
        """ Set min_address value.

            Notes:
                Lowest address in the MultiCast range

                
                This attribute is named `minAddress` in VSD API.
                
        """
        self._min_address = value

    min_address = property(_get_min_address, _set_min_address)
    